@@ -7,19 +7,17 @@ from flask import Flask
 from flask import g
 from flask import request
 from flask import session
-from flask_babel import Babel
 from flask_themer import FileSystemThemeLoader
 from flask_themer import render_template
 from flask_themer import Themer
 
-from .i18n import available_language_codes
+from .i18n import setup_i18n
 from .ldap_backend.backend import init_backend
 from .oidc.oauth import setup_oauth
 
 
 def setup_config(app, config=None, validate=True):
     import canaille.configuration
-    import canaille.installation
 
     app.config.from_mapping(
         {
@@ -38,8 +36,10 @@ def setup_config(app, config=None, validate=True):
             "Either create conf/config.toml or set the 'CONFIG' variable environment."
         )
 
-    if app.debug:  # pragma: no cover
-        canaille.installation.setup_keypair(app.config)
+    if app.debug and "JWT" in app.config:  # pragma: no cover
+        import canaille.oidc.installation
+
+        canaille.oidc.installation.setup_keypair(app.config)
 
     if validate:
         canaille.configuration.validate(app.config)
@@ -91,32 +91,7 @@ def setup_logging(app):
 
 
 def setup_jinja(app):
-    from .flaskutils import timestamp
-
     app.jinja_env.filters["len"] = len
-    app.jinja_env.filters["timestamp"] = timestamp
-
-
-def setup_i18n(app):
-    babel = Babel(app)
-
-    @app.before_request
-    def before_request():
-        g.available_language_codes = available_language_codes(babel)
-
-    @babel.localeselector
-    def get_locale():
-        from .flaskutils import current_user
-
-        user = current_user()
-        available_language_codes = getattr(g, "available_language_codes", [])
-        if user is not None and user.preferredLanguage in available_language_codes:
-            return user.preferredLanguage
-
-        if app.config.get("LANGUAGE"):
-            return app.config.get("LANGUAGE")
-
-        return request.accept_languages.best_match(available_language_codes)
 
 
 def setup_themer(app):
@@ -177,9 +152,6 @@ def create_app(config=None, validate=True):
 
             return {
                 "has_smtp": "SMTP" in app.config,
-                "has_password_recovery": app.config.get(
-                    "ENABLE_PASSWORD_RECOVERY", True
-                ),
                 "logo_url": app.config.get("LOGO"),
                 "favicon_url": app.config.get("FAVICON", app.config.get("LOGO")),
                 "website_name": app.config.get("NAME", "Canaille"),
