@@ -17,6 +17,7 @@ from flask import send_file
 from flask import session
 from flask import url_for
 from flask_babel import gettext as _
+from flask_babel import refresh
 from flask_themer import render_template
 from werkzeug.datastructures import CombinedMultiDict
 from werkzeug.datastructures import FileStorage
@@ -28,6 +29,7 @@ from .apputils import obj_to_b64
 from .apputils import profile_hash
 from .flaskutils import current_user
 from .flaskutils import permissions_needed
+from .flaskutils import render_htmx_template
 from .flaskutils import smtp_needed
 from .flaskutils import user_needed
 from .forms import FirstLoginForm
@@ -37,6 +39,7 @@ from .forms import LoginForm
 from .forms import PasswordForm
 from .forms import PasswordResetForm
 from .forms import profile_form
+from .forms import TableForm
 from .mails import send_invitation_mail
 from .mails import send_password_initialization_mail
 from .mails import send_password_reset_mail
@@ -47,6 +50,15 @@ from .models import User
 bp = Blueprint("account", __name__)
 
 
+@bp.context_processor
+def global_processor():
+    return {
+        "has_password_recovery": current_app.config.get(
+            "ENABLE_PASSWORD_RECOVERY", True
+        ),
+    }
+
+
 @bp.route("/")
 def index():
     user = current_user()
@@ -159,7 +171,7 @@ def firstlogin(uid):
     if send_password_initialization_mail(user):
         flash(
             _(
-                "A password initialization link has been sent at your email address. You should receive it within 10 minutes."
+                "A password initialization link has been sent at your email address. You should receive it within a few minutes."
             ),
             "success",
         )
@@ -169,11 +181,18 @@ def firstlogin(uid):
     return render_template("firstlogin.html", form=form, uid=uid)
 
 
-@bp.route("/users")
+@bp.route("/users", methods=["GET", "POST"])
 @permissions_needed("manage_users")
 def users(user):
-    users = User.all()
-    return render_template("users.html", users=users, menuitem="users")
+    table_form = TableForm(User, fields=user.read | user.write, formdata=request.form)
+    if request.form and not table_form.validate():
+        abort(404)
+
+    return render_htmx_template(
+        "users.html",
+        menuitem="users",
+        table_form=table_form,
+    )
 
 
 @dataclass
@@ -315,7 +334,7 @@ def registration(data, hash):
     if "groups" not in form and invitation.groups:
         form["groups"] = wtforms.SelectMultipleField(
             _("Groups"),
-            choices=[(group.dn, group.name) for group in Group.all()],
+            choices=[(group.id, group.display_name) for group in Group.query()],
             render_kw={"readonly": "true"},
         )
     form.process(CombinedMultiDict((request.files, request.form)) or None, data=data)
@@ -354,22 +373,15 @@ def registration(data, hash):
 
 
 def profile_create(current_app, form):
-    user = User(
-        objectClass=current_app.config["LDAP"].get(
-            "USER_CLASS", User.DEFAULT_OBJECT_CLASS
-        )
-    )
+    user = User()
     for attribute in form:
-        if attribute.name in user.may + user.must:
+        if attribute.name in user.may() + user.must():
             if isinstance(attribute.data, FileStorage):
                 data = attribute.data.stream.read()
             else:
                 data = attribute.data
 
-            if user.ldap_object_attributes()[attribute.name].single_value:
-                user[attribute.name] = data
-            else:
-                user[attribute.name] = [data]
+            user[attribute.name] = data
 
         if "jpegPhoto" in form and form["jpegPhoto_delete"].data:
             user["jpegPhoto"] = None
@@ -378,9 +390,10 @@ def profile_create(current_app, form):
     user.save()
 
     if "groups" in form:
-        groups = [Group.get(group_dn) for group_dn in form["groups"].data]
+        groups = [Group.get(group_id) for group_id in form["groups"].data]
         for group in groups:
             group.add_member(user)
+            group.save()
 
     if form["password1"].data:
         user.set_password(form["password1"].data)
@@ -413,7 +426,7 @@ def profile_edition(user, username):
         if send_password_initialization_mail(user):
             flash(
                 _(
-                    "A password initialization link has been sent at the user email address. It should be received within 10 minutes."
+                    "A password initialization link has been sent at the user email address. It should be received within a few minutes."
                 ),
                 "success",
             )
@@ -430,7 +443,7 @@ def profile_edition(user, username):
         if send_password_reset_mail(user):
             flash(
                 _(
-                    "A password reset link has been sent at the user email address. It should be received within 10 minutes."
+                    "A password reset link has been sent at the user email address. It should be received within a few minutes."
                 ),
                 "success",
             )
@@ -462,7 +475,7 @@ def profile_edit(editor, username):
     }
 
     if "groups" in fields:
-        data["groups"] = [g.dn for g in user.groups]
+        data["groups"] = [g.id for g in user.groups]
 
     form = profile_form(editor.write, editor.read)
     form.process(CombinedMultiDict((request.files, request.form)) or None, data=data)
@@ -474,7 +487,7 @@ def profile_edit(editor, username):
         else:
             for attribute in form:
                 if (
-                    attribute.name in user.may + user.must
+                    attribute.name in user.may() + user.must()
                     and attribute.name in editor.write
                 ):
                     if isinstance(attribute.data, FileStorage):
@@ -482,10 +495,8 @@ def profile_edit(editor, username):
                     else:
                         data = attribute.data
 
-                    if user.ldap_object_attributes()[attribute.name].single_value:
-                        user[attribute.name] = data
-                    else:
-                        user[attribute.name] = [data]
+                    user[attribute.name] = data
+
                 elif attribute.name == "groups" and "groups" in editor.write:
                     user.set_groups(attribute.data)
 
@@ -499,14 +510,15 @@ def profile_edit(editor, username):
             ):
                 user.set_password(form["password1"].data)
 
-            if (
-                "preferredLanguage" in request.form
-                and form["preferredLanguage"].data == "auto"
-            ):
-                user.preferredLanguage = None
+            if "preferredLanguage" in request.form:
+                # Refresh the babel cache in case the lang is updated
+                refresh()
+
+                if form["preferredLanguage"].data == "auto":
+                    user.preferredLanguage = None
 
-            flash(_("Profile updated successfuly."), "success")
             user.save()
+            flash(_("Profile updated successfuly."), "success")
             return redirect(url_for("account.profile_edition", username=username))
 
     return render_template(
@@ -563,7 +575,7 @@ def forgotten():
 
     user = User.get(form.login.data)
     success_message = _(
-        "A password reset link has been sent at your email address. You should receive it within 10 minutes."
+        "A password reset link has been sent at your email address. You should receive it within a few minutes."
     )
     if current_app.config.get("HIDE_INVALID_LOGINS", True) and (
         not user or not user.can_edit_self
@@ -578,7 +590,7 @@ def forgotten():
                 "We cannot send a password reset email.",
                 user=user.name,
             ),
-            "success",
+            "error",
         )
         return render_template("forgotten-password.html", form=form)
 
