@@ -17,6 +17,7 @@ from .apputils import profile_hash
 DEFAULT_SMTP_HOST = "localhost"
 DEFAULT_SMTP_PORT = 25
 DEFAULT_SMTP_TLS = False
+DEFAULT_SMTP_SSL = False
 
 
 def logo():
@@ -71,8 +72,14 @@ def send_email(subject, recipient, text, html, attachements=None):
             value, maintype=maintype, subtype=subtype, cid=cid
         )
 
+    smtp = None
     try:
-        with smtplib.SMTP(
+        connection_func = (
+            smtplib.SMTP_SSL
+            if current_app.config["SMTP"].get("SSL", DEFAULT_SMTP_SSL)
+            else smtplib.SMTP
+        )
+        with connection_func(
             host=current_app.config["SMTP"].get("HOST", DEFAULT_SMTP_HOST),
             port=current_app.config["SMTP"].get("PORT", DEFAULT_SMTP_PORT),
         ) as smtp:
@@ -95,6 +102,34 @@ def send_email(subject, recipient, text, html, attachements=None):
     return True
 
 
+def send_test_mail(email):
+    base_url = url_for("account.index", _external=True)
+    logo_cid, logo_filename, logo_raw = logo()
+
+    subject = _("Test email from {website_name}").format(
+        website_name=current_app.config.get("NAME", "Canaille")
+    )
+    text_body = render_template(
+        "mail/test.txt",
+        site_name=current_app.config.get("NAME", "Canaille"),
+        site_url=base_url,
+    )
+    html_body = render_template(
+        "mail/test.html",
+        site_name=current_app.config.get("NAME", "Canaille"),
+        site_url=base_url,
+        logo=f"cid:{logo_cid[1:-1]}" if logo_cid else None,
+    )
+
+    return send_email(
+        subject=subject,
+        recipient=email,
+        text=text_body,
+        html=html_body,
+        attachements=[(logo_cid, logo_filename, logo_raw)] if logo_filename else None,
+    )
+
+
 def send_password_reset_mail(user):
     base_url = url_for("account.index", _external=True)
     reset_url = url_for(
