@@ -1,5 +1,4 @@
 import datetime
-import uuid
 
 from authlib.oauth2.rfc6749 import AuthorizationCodeMixin
 from authlib.oauth2.rfc6749 import ClientMixin
@@ -9,9 +8,9 @@ from canaille.ldap_backend.ldapobject import LDAPObject
 
 
 class Client(LDAPObject, ClientMixin):
-    object_class = ["oauthClient"]
+    ldap_object_class = ["oauthClient"]
     base = "ou=clients,ou=oauth"
-    id = "oauthClientID"
+    rdn_attribute = "oauthClientID"
 
     client_info_attributes = {
         "client_id": "oauthClientID",
@@ -39,6 +38,7 @@ class Client(LDAPObject, ClientMixin):
     }
 
     attribute_table = {
+        "id": "dn",
         "description": "description",
         "preconsent": "oauthPreconsent",
         # post_logout_redirect_uris is not yet supported by authlib
@@ -89,17 +89,32 @@ class Client(LDAPObject, ClientMixin):
 
     @property
     def client_metadata(self):
-        return {
+        metadata = {
             attribute_name: getattr(self, attribute_name)
             for attribute_name in self.client_metadata_attributes
         }
+        metadata["scope"] = " ".join(metadata["scope"])
+        return metadata
+
+    def delete(self):
+        for consent in Consent.query(client=self):
+            consent.delete()
+
+        for code in AuthorizationCode.query(client=self):
+            code.delete()
+
+        for token in Token.query(client=self):
+            token.delete()
+
+        super().delete()
 
 
 class AuthorizationCode(LDAPObject, AuthorizationCodeMixin):
-    object_class = ["oauthAuthorizationCode"]
+    ldap_object_class = ["oauthAuthorizationCode"]
     base = "ou=authorizations,ou=oauth"
-    id = "oauthAuthorizationCodeID"
+    rdn_attribute = "oauthAuthorizationCodeID"
     attribute_table = {
+        "id": "dn",
         "authorization_code_id": "oauthAuthorizationCodeID",
         "description": "description",
         "code": "oauthCode",
@@ -136,10 +151,11 @@ class AuthorizationCode(LDAPObject, AuthorizationCodeMixin):
 
 
 class Token(LDAPObject, TokenMixin):
-    object_class = ["oauthToken"]
+    ldap_object_class = ["oauthToken"]
     base = "ou=tokens,ou=oauth"
-    id = "oauthTokenID"
+    rdn_attribute = "oauthTokenID"
     attribute_table = {
+        "id": "dn",
         "token_id": "oauthTokenID",
         "access_token": "oauthAccessToken",
         "description": "description",
@@ -193,15 +209,16 @@ class Token(LDAPObject, TokenMixin):
         return bool(self.revokation_date)
 
     def check_client(self, client):
-        return client.client_id == Client.get(self.client).client_id
+        return client.client_id == self.client.client_id
 
 
 class Consent(LDAPObject):
-    object_class = ["oauthConsent"]
+    ldap_object_class = ["oauthConsent"]
     base = "ou=consents,ou=oauth"
-    id = "cn"
+    rdn_attribute = "cn"
     attribute_table = {
-        "cn": "cn",
+        "id": "dn",
+        "consent_id": "cn",
         "subject": "oauthSubject",
         "client": "oauthClient",
         "scope": "oauthScope",
@@ -209,24 +226,23 @@ class Consent(LDAPObject):
         "revokation_date": "oauthRevokationDate",
     }
 
-    def __init__(self, *args, **kwargs):
-        if "cn" not in kwargs:
-            kwargs["cn"] = str(uuid.uuid4())
-
-        super().__init__(*args, **kwargs)
+    @property
+    def revoked(self):
+        return bool(self.revokation_date)
 
     def revoke(self):
         self.revokation_date = datetime.datetime.now()
         self.save()
 
-        tokens = Token.filter(
+        tokens = Token.query(
             oauthClient=self.client,
             oauthSubject=self.subject,
         )
+        tokens = [token for token in tokens if not token.revoked]
         for t in tokens:
-            different_scope = any(scope not in t.scope[0] for scope in self.scope)
-            if t.revoked or different_scope:
-                continue
-
             t.revokation_date = self.revokation_date
             t.save()
+
+    def restore(self):
+        self.revokation_date = None
+        self.save()
